"""
Test ADT Pulse system setup, shutdown, and general functionality.

Tests the system initialization and attributes of the main ADT Pulse system.
"""

import unittest
import adtpulsepy.helpers.util as UTIL
from adtpulsepy.devices.alarm import ADTPulseAlarm

DATA = """{'update': [{'data': {'client': {'site': {'state': {'setSite': '000000', 'privacyLinkName': 'Privacy Policy', 'privacyLinkUrl': 'https://www.adt.com/about-adt/legal/pulse-portal-privacy', 'clientInactivityTimeoutMins': 10, 'cmsIdLabel': 'CS #', 'cmsId': 'T210176332', 'postalCode': '00000', 'panelTypeTxt': 'TSSC Life Safety Module'}, 'commands': {'setSite': {'params': {'site': {'options': [{'value': '151120zb769920', 'label': 'Ty Amell'}], 'type': 'select'}}, 'method': 'post', 'action': 'rest/adt/ui/client/site/setSite'}, 'signOut': {'method': 'post', 'action': 'rest/adt/ui/client/site/signOut', 'label': 'Sign Out'}}, 'id': 'site', 'name': 'Sites', 'userName': 'tyamell@gmail.com', 'serverVersion': '10.0.0-60', 'gatewayVersion': '10.0.0-271', 'locale': 'en_US', 'isOwner': True, 'timeZoneOffsetMillis': -25200000, 'timeZoneIdentifier': 'America/Los_Angeles', 'timeZoneLastDSTChangeMillis': 1520762399999, 'timeZoneOffsetPreDSTChangeMillis': -28800000}, 'summary': {'state': {'systemIcon': 'disarmed', 'numTrouble': 0, 'numOpen': 1, 'numMotion': 0, 'statusTxt': 'Disarmed', 'sensorStatusTxt': '1 Sensor Open', 'delayEndTs': 0, 'armType': 'disarmed'}, 'id': 'summary', 'name': 'Security'}, 'security': {'state': {'label': 'Arm', 'disabled': False, 'busy': False}, 'items': [{'label': 'Arm Away', 'tags': 'armAway', 'commands': {'panelAction': {'method': 'post', 'action': 'rest/adt/ui/client/security/setArmState&armstate=disarmed&arm=away', 'busyStatusTxt': 'Arming Away'}}}, {'label': 'Arm Stay', 'tags': 'armStay', 'commands': {'panelAction': {'method': 'post', 'action': 'rest/adt/ui/client/security/setArmState&armstate=disarmed&arm=stay', 'busyStatusTxt': 'Arming Stay'}}}], 'id': 'security', 'name': 'Security'}, 'shift': {'state': {'label': 'Vacation', 'disabled': False, 'busy': False, 'pendingShiftMode': 'shiftModes/shiftName5'}, 'commands': {'setShiftMode': {'params': {'pendingShiftMode': {'options': [{'value': 'shiftModes/shiftName1', 'label': 'At Home'}, {'value': 'shiftModes/shiftName2', 'label': 'Out for the Day'}, {'value': 'shiftModes/shiftName3', 'label': 'Asleep'}, {'value': 'shiftModes/shiftName4', 'label': 'Be Right Back'}, {'value': 'shiftModes/shiftName5', 'label': 'Vacation'}, {'value': 'shiftModes/shiftName6', 'label': 'Custom 1'}, {'value': 'shiftModes/shiftName7', 'label': 'Custom 2'}, {'value': 'shiftModes/shiftName8', 'label': 'Custom 3'}], 'type': 'select'}}, 'method': 'post', 'action': 'rest/adt/ui/client/shift/setCurrentShiftMode'}}, 'id': 'shift', 'name': 'Modes'}, 'messaging': {'items': [{'type': 'info', 'statusTxt': 'Last sign in: Oct 26, 2018 1:20 PM', 'isDismissable': True, 'dismissAfterSeconds': 5}], 'id': 'messaging'}, 'hvwSettings': {'state': {'show': True, 'floors': '28;taigg Haaraigmmjzmdaogatia}} Vaa}gigmajmmq}a} ;default tvjhf Haa}ajjvjhvohmwbzwda}dg}w Vaa}mompajvjd}a}', 'labels': ';', 'devices': 'heaE8VER1 txaE2VER1 vaeE7VER1 vaqE5VER1 vmqE4VER1 tawE6VER1 tc|2 ;tijE3VER1 he}E1VER1'}, 'commands': {'refreshHomeview': {'method': 'POST', 'action': 'rest/adt/ui/client/hvwSettings/refreshHomeView'}, 'saveHomeviewData': {'params': {'floors': {'type': 'textInput', 'minChars': 3, 'maxChars': 4000}, 'labels': {'type': 'textInput', 'minChars': 0, 'maxChars': 4000}, 'devices': {'type': 'textInput', 'minChars': 0, 'maxChars': 4000}}, 'method': 'POST', 'action': 'rest/adt/ui/client/hvwSettings/saveHomeviewData'}}, 'id': 'hvwSettings', 'name': 'Home View'}, 'thermostat': {'items': [], 'id': 'thermostat', 'name': 'Thermostats', 'numTrouble': 0, 'icon': 'symThermostats'}, 'sensor': {'items': [{'state': {'bypassed': False, 'isTripped': True, 'icon': 'devStatOpen', 'statusTxt': 'Open', 'sort': 35}, 'id': 'sensor-3', 'devIndex': 'E2VER1', 'name': 'BACK DOOR', 'tags': 'sensor,doorWindow', 'zone': 2}, {'state': {'bypassed': False, 'isTripped': False, 'icon': 'devStatOK', 'statusTxt': 'Closed', 'sort': 0}, 'id': 'sensor-4', 'devIndex': 'E1VER1', 'name': 'FRONT DOOR', 'tags': 'sensor,doorWindow', 'zone': 1}, {'state': {'bypassed': False, 'isTripped': False, 'icon': 'devStatOK', 'statusTxt': 'No Motion', 'sort': 0}, 'id': 'sensor-2', 'devIndex': 'E3VER1', 'name': 'Hall Way Motion', 'tags': 'sensor,motion', 'zone': 3}, {'state': {'bypassed': False, 'isTripped': False, 'icon': 'devStatOK', 'statusTxt': 'Closed', 'sort': 0}, 'id': 'sensor-8', 'devIndex': 'E4VER1', 'name': 'Inside Garage Door', 'tags': 'sensor,doorWindow', 'zone': 4}, {'state': {'bypassed': False, 'isTripped': False, 'icon': 'devStatOK', 'statusTxt': 'Closed', 'sort': 0}, 'id': 'sensor-11', 'devIndex': 'E7VER1', 'name': 'Laundry Room Window 1', 'tags': 'sensor,doorWindow', 'zone': 7}, {'state': {'bypassed': False, 'isTripped': False, 'icon': 'devStatOK', 'statusTxt': 'Closed', 'sort': 0}, 'id': 'sensor-12', 'devIndex': 'E8VER1', 'name': 'Laundry Room Window 2', 'tags': 'sensor,doorWindow', 'zone': 8}, {'state': {'bypassed': False, 'isTripped': False, 'icon': 'devStatOK', 'statusTxt': 'Closed', 'sort': 0}, 'id': 'sensor-10', 'devIndex': 'E6VER1', 'name': 'Office Window', 'tags': 'sensor,doorWindow', 'zone': 6}, {'state': {'bypassed': False, 'isTripped': False, 'icon': 'devStatOK', 'statusTxt': 'Closed', 'sort': 0}, 'id': 'sensor-9', 'devIndex': 'E5VER1', 'name': 'Side Door', 'tags': 'sensor,doorWindow', 'zone': 5}], 'id': 'sensor', 'name': 'Sensors'}, 'door': {'items': [], 'id': 'door', 'name': 'Doors', 'numTrouble': 0, 'icon': 'symDoors'}, 'lighting': {'items': [{'state': {'icon': 'devStatOffline', 'statusTxt': 'Offline', 'sort': 90, 'lastEvent': '11/30&nbsp;12:22&nbsp;AM', 'lastEventTs': 1448871754589, 'troubleTxt': 'Offline', 'busy': False}, 'id': 'lighting-18', 'devIndex': '2', 'name': 'Switch', 'tags': 'lighting,dimmer,zw'}], 'id': 'lighting', 'name': 'Switches', 'numTrouble': 1, 'icon': 'symSwitches'}, 'hvwData': {'items': [{'state': {'icon': 'devStatOpen', 'statusTxt': 'BACK DOOR - Open', 'activityTs': 0}, 'id': 'sensor-3', 'devIndex': 'E2VER1', 'name': 'BACK DOOR', 'tags': 'sensor,doorWindow'}, {'state': {'icon': 'devStatOK', 'statusTxt': 'FRONT DOOR - Closed', 'activityTs': 0}, 'id': 'sensor-4', 'devIndex': 'E1VER1', 'name': 'FRONT DOOR', 'tags': 'sensor,doorWindow'}, {'state': {'icon': 'devStatOK', 'statusTxt': 'Hall Way Motion - No Motion', 'activityTs': 0}, 'id': 'sensor-2', 'devIndex': 'E3VER1', 'name': 'Hall Way Motion', 'tags': 'sensor,motion'}, {'state': {'icon': 'devStatOK', 'statusTxt': 'Inside Garage Door - Closed', 'activityTs': 0}, 'id': 'sensor-8', 'devIndex': 'E4VER1', 'name': 'Inside Garage Door', 'tags': 'sensor,doorWindow'}, {'state': {'icon': 'devStatOK', 'statusTxt': 'Laundry Room Window 1 - Closed', 'activityTs': 0}, 'id': 'sensor-11', 'devIndex': 'E7VER1', 'name': 'Laundry Room Window 1', 'tags': 'sensor,doorWindow'}, {'state': {'icon': 'devStatOK', 'statusTxt': 'Laundry Room Window 2 - Closed', 'activityTs': 0}, 'id': 'sensor-12', 'devIndex': 'E8VER1', 'name': 'Laundry Room Window 2', 'tags': 'sensor,doorWindow'}, {'state': {'icon': 'devStatOK', 'statusTxt': 'Office Window - Closed', 'activityTs': 0}, 'id': 'sensor-10', 'devIndex': 'E6VER1', 'name': 'Office Window', 'tags': 'sensor,doorWindow'}, {'state': {'icon': 'devStatOK', 'statusTxt': 'Side Door - Closed', 'activityTs': 0}, 'id': 'sensor-9', 'devIndex': 'E5VER1', 'name': 'Side Door', 'tags': 'sensor,doorWindow'}, {'state': {'icon': 'devStatOffline', 'statusTxt': 'Switch - Offline', 'activityTs': 0}, 'id': 'lighting-18', 'devIndex': '2', 'name': 'Switch', 'tags': 'lighting,dimmer,zw'}], 'id': 'hvwData', 'ts': 1540585226589}, 'energyMeter': {'items': [], 'id': 'energyMeter', 'name': 'Energy', 'numTrouble': 0, 'icon': 'symEnergy'}, 'history': {'commands': {'getEvents': {'params': {'reqType': {'options': [{'value': 'all', 'label': 'All'}, {'value': 'notableEvents', 'label': 'Notable Events'}, {'value': 'alerts', 'label': 'Alerts'}, {'value': 'automations', 'label': 'Automations'}, {'value': 'schedules', 'label': 'Schedules'}, {'value': 'system', 'label': 'System'}, {'value': 'siteAccess', 'label': 'Site Access'}, {'value': 'media', 'label': 'Pictures/Clips'}], 'type': 'select'}, 'startTs': {'type': 'timeMillis', 'defaultValue': -1}, 'endTs': {'type': 'timeMillis', 'defaultValue': -1}, 'minEvents': {'type': 'range', 'min': 0.0, 'max': 10000.0, 'step': 1.0, 'defaultValue': 20.0}, 'maxEvents': {'type': 'range', 'min': 1.0, 'max': 5000.0, 'step': 1.0, 'defaultValue': 5000.0}, 'tags': {'type': 'textInput', 'minChars': 0, 'maxChars': 255, 'regExp': '[a-zA-Z0-9\\.\\-\\_, ]?'}, 'queryId': {'type': 'textInput', 'minChars': 0, 'maxChars': 255, 'regExp': '[a-z0-9-]+'}, 'changesOnlySince': {'type': 'timeMillis', 'defaultValue': -1}, 'fields': {'options': [{'value': 'basic', 'label': 'basic'}, {'value': 'verbose', 'label': 'verbose'}], 'type': 'select'}}, 'method': 'post', 'action': 'rest/adt/ui/client/history/getEvents'}, 'getEventsForDevice': {'params': {'startTs': {'type': 'timeMillis', 'defaultValue': -1}, 'endTs': {'type': 'timeMillis', 'defaultValue': -1}, 'minEvents': {'type': 'range', 'min': 0.0, 'max': 10000.0, 'step': 1.0, 'defaultValue': 20.0}, 'maxEvents': {'type': 'range', 'min': 1.0, 'max': 5000.0, 'step': 1.0, 'defaultValue': 5000.0}, 'tags': {'type': 'textInput', 'minChars': 0, 'maxChars': 255, 'regExp': '[a-zA-Z0-9\\.\\-\\_, ]?'}, 'queryId': {'type': 'textInput', 'minChars': 0, 'maxChars': 255, 'regExp': '[a-z0-9-]+'}, 'changesOnlySince': {'type': 'timeMillis', 'defaultValue': -1}, 'deviceId': {'options': [{'value': 'panel-1', 'label': 'ADT: TSSC Life Safety Module'}, {'value': 'sensor-3', 'label': 'BACK DOOR'}, {'value': 'sensor-4', 'label': 'FRONT DOOR'}, {'value': 'sensor-2', 'label': 'Hall Way Motion'}, {'value': 'sensor-8', 'label': 'Inside Garage Door'}, {'value': 'remote-19', 'label': 'Key Fob'}, {'value': 'remote-6', 'label': 'KEYPAD #1'}, {'value': 'sensor-11', 'label': 'Laundry Room Window 1'}, {'value': 'sensor-12', 'label': 'Laundry Room Window 2'}, {'value': 'sensor-10', 'label': 'Office Window'}, {'value': 'sensor-9', 'label': 'Side Door'}, {'value': 'lighting-18', 'label': 'Switch'}], 'type': 'select'}, 'fields': {'options': [{'value': 'basic', 'label': 'basic'}, {'value': 'verbose', 'label': 'verbose'}], 'type': 'select'}}, 'method': 'post', 'action': 'rest/adt/ui/client/history/getEventsForDevice'}, 'getEventsForUser': {'params': {'startTs': {'type': 'timeMillis', 'defaultValue': -1}, 'endTs': {'type': 'timeMillis', 'defaultValue': -1}, 'minEvents': {'type': 'range', 'min': 0.0, 'max': 10000.0, 'step': 1.0, 'defaultValue': 20.0}, 'maxEvents': {'type': 'range', 'min': 1.0, 'max': 5000.0, 'step': 1.0, 'defaultValue': 5000.0}, 'tags': {'type': 'textInput', 'minChars': 0, 'maxChars': 255, 'regExp': '[a-zA-Z0-9\\.\\-\\_, ]?'}, 'queryId': {'type': 'textInput', 'minChars': 0, 'maxChars': 255, 'regExp': '[a-z0-9-]+'}, 'changesOnlySince': {'type': 'timeMillis', 'defaultValue': -1}, 'userName': {'type': 'textInput', 'minChars': 6, 'maxChars': 255, 'regExp': '.*'}, 'fields': {'options': [{'value': 'basic', 'label': 'basic'}, {'value': 'verbose', 'label': 'verbose'}], 'type': 'select'}}, 'method': 'post', 'action': 'rest/adt/ui/client/history/getEventsForUser'}, 'getGraphDataForThermostat': {'params': {'startTs': {'type': 'timeMillis', 'defaultValue': -1}, 'endTs': {'type': 'timeMillis', 'defaultValue': -1}, 'maxEvents': {'type': 'range', 'min': 1.0, 'max': 5000.0, 'step': 1.0, 'defaultValue': 5000.0}, 'queryId': {'type': 'textInput', 'minChars': 0, 'maxChars': 255, 'regExp': '[a-z0-9-]+'}, 'changesOnlySince': {'type': 'timeMillis', 'defaultValue': -1}, 'deviceId': {'type': 'textInput', 'minChars': 1, 'maxChars': 255, 'regExp': '.*'}, 'scaling': {'type': 'textInput', 'minChars': 1, 'maxChars': 3, 'regExp': '[0-9]{0,2}(h|d|w|m)', 'defaultValue': '1d'}}, 'method': 'post', 'action': 'rest/adt/ui/client/history/getGraphDataForThermostat'}, 'getGraphDataForEnergyDevice': {'params': {'startTs': {'type': 'timeMillis', 'defaultValue': -1}, 'endTs': {'type': 'timeMillis', 'defaultValue': -1}, 'maxEvents': {'type': 'range', 'min': 1.0, 'max': 5000.0, 'step': 1.0, 'defaultValue': 5000.0}, 'queryId': {'type': 'textInput', 'minChars': 0, 'maxChars': 255, 'regExp': '[a-z0-9-]+'}, 'changesOnlySince': {'type': 'timeMillis', 'defaultValue': -1}, 'deviceId': {'type': 'textInput', 'minChars': 1, 'maxChars': 255, 'regExp': '.*'}, 'scaling': {'type': 'textInput', 'minChars': 1, 'maxChars': 3, 'regExp': '[0-9]{0,2}(h|d|w|m)', 'defaultValue': '1d'}}, 'method': 'post', 'action': 'rest/adt/ui/client/history/getGraphDataForEnergyDevice'}, 'stopEventUpdates': {'params': {'queryId': {'type': 'textInput', 'minChars': 0, 'maxChars': 255, 'regExp': '[a-z0-9-]+'}}, 'method': 'post', 'action': 'rest/adt/ui/client/history/stopEventUpdates'}, 'mediaEventDelete': {'params': {'deviceId': {'type': 'textInput', 'minChars': 3, 'maxChars': 255}, 'eventTs': {'type': 'timeMillis', 'defaultValue': -1}}, 'method': 'post', 'action': 'rest/adt/ui/client/history/mediaEventDelete'}, 'mediaEventDownload': {'params': {'deviceId': {'type': 'textInput', 'minChars': 3, 'maxChars': 255}, 'eventTs': {'type': 'timeMillis', 'defaultValue': -1}}, 'method': 'post', 'action': 'rest/adt/ui/client/history/mediaEventDownload'}, 'mediaEventEmail': {'params': {'deviceId': {'type': 'textInput', 'minChars': 3, 'maxChars': 255}, 'eventTs': {'type': 'timeMillis', 'defaultValue': -1}, 'emailAddress': {'type': 'textInput', 'minChars': 5, 'maxChars': 255}, 'emailSubject': {'type': 'textInput', 'minChars': 0, 'maxChars': 255}, 'emailMessage': {'type': 'textInput', 'minChars': 0, 'maxChars': 8000}}, 'method': 'post', 'action': 'rest/adt/ui/client/history/mediaEventEmail'}}, 'id': 'history', 'retentionUiHistoryDays': 30, 'retentionMediaDays': 30, 'todayStartMillis': 1540537200000, 'yesterdayStartMillis': 1540450800000}, 'panel': {'state': {'chime': False, 'quickExit': False}, 'id': 'panel', 'name': 'Security Panel', 'deviceId': 'panel-1', 'gatewayVer': '10.0.0-271', 'panelName': 'ADT: TSSC Life Safety Module', 'panelFirmwareVer': 'TSSC Panel-01.00.03093-8.145-0, Radio-3093-8.397b, RadioHW-PHS8-USA'}, 'pushNotificationSettings': {'commands': {'registerPushNotification': {'params': {'channelID': {'type': 'textInput', 'minChars': 1, 'maxChars': 200}, 'deviceID': {'type': 'textInput', 'minChars': 1, 'maxChars': 200}, 'deviceName': {'type': 'textInput', 'minChars': 1, 'maxChars': 200}, 'deviceModel': {'type': 'textInput', 'minChars': 1, 'maxChars': 200}, 'deviceType': {'type': 'textInput', 'minChars': 1, 'maxChars': 30}}, 'method': 'post', 'action': 'rest/adt/ui/client/pushNotificationSettings/registerPushNotification', 'label': 'Enable push notification'}, 'unRegisterPushNotification': {'params': {'device': {'options': [{'value': '1097835812', 'channelID': 'e1caa244-e23b-4f69-bf6d-58a29478a401', 'label': 'TRA Personal'}], 'type': 'select'}}, 'method': 'post', 'action': 'rest/adt/ui/client/pushNotificationSettings/unRegisterPushNotification', 'label': 'Remove push notification'}}, 'id': 'pushNotificationSettings', 'name': 'Push Notification'}, 'user': {'commands': {'changeUsername': {'params': {'newUsername': {'caption': [{'id': 1, 'label': 'Username may be composed of letters, numbers or symbols.'}, {'id': 2, 'label': 'Username must have between 6 and 50 characters'}, {'id': 3, 'label': 'Username must be a valid email address'}], 'type': 'textInput', 'minChars': 6, 'maxChars': 50, 'defaultValue': 'tyamell@gmail.com', 'label': 'New Username'}, 'currentPassword': {'type': 'textInput', 'minChars': 1, 'maxChars': 50}}, 'method': 'POST', 'action': 'rest/adt/ui/client/user/changeUsername'}, 'changeDisplayName': {'params': {'displayName': {'type': 'textInput', 'minChars': 1, 'maxChars': 30, 'defaultValue': 'Ty Amell', 'label': 'Display Name'}}, 'method': 'POST', 'action': 'rest/adt/ui/client/user/changeDisplayName'}, 'changeLocale': {'params': {'locale': {'options': [{'value': 'en_US', 'label': 'English (United States)'}, {'value': 'en_CA', 'label': 'English (Canada)'}], 'type': 'select', 'label': 'Language and Region'}}, 'method': 'POST', 'action': 'rest/adt/ui/client/user/changeLocale'}, 'changeTemperatureUnit': {'params': {'temperatureUnit': {'options': [{'value': 'C', 'label': 'Celsius'}, {'value': 'F', 'label': 'Fahrenheit'}], 'type': 'select', 'label': 'Temperature Units'}}, 'method': 'POST', 'action': 'rest/adt/ui/client/user/changeTemperatureUnit'}, 'changePassword': {'params': {'newPassword': {'caption': [{'id': 1, 'label': 'Password must not contain your email address, username or actual name'}, {'id': 2, 'label': 'Password must not contain more than 2 of the same characters in a row'}, {'id': 3, 'label': 'Password must have at least 1 letter'}, {'id': 4, 'label': 'Password must have at least 1 number or symbol (!,@,# etc.)'}, {'id': 5, 'label': 'Password must have at least 8 characters'}], 'type': 'textInput', 'minChars': 8}, 'currentPassword': {'type': 'textInput', 'minChars': 1, 'maxChars': 50}}, 'method': 'POST', 'action': 'rest/adt/ui/client/user/changePassword'}, 'changeSecurityQs': {'params': {'securityQ2': {'options': [{'value': 0, 'label': 'What was your childhood nickname?'}, {'value': 1, 'label': "What is your father's middle name?"}, {'value': 2, 'label': "What is your oldest sibling's middle name?"}, {'value': 3, 'label': "What is your youngest sibling's middle name?"}, {'value': 4, 'label': 'What is the last name of your childhood best friend?'}, {'value': 5, 'label': 'What is the last name of the boy or girl that you first kissed?'}, {'value': 6, 'label': 'What is the last name of your third grade teacher?'}, {'value': 7, 'label': 'What is the last name of your fifth grade teacher?'}, {'value': 8, 'label': 'What is the last name of your favorite elementary school teacher?'}, {'value': 9, 'label': 'What is the last name of your favorite high school teacher?'}, {'value': 10, 'label': 'What is the last name of your first roommate during college?'}, {'value': 11, 'label': 'What is the last name of your first boss?'}, {'value': 12, 'label': 'What is the last name of the funniest friend you know?'}, {'value': 13, 'label': 'What was the name of your first pet?'}, {'value': 14, 'label': 'What was the name of your first stuffed animal?'}, {'value': 15, 'label': 'Who was your childhood hero?'}, {'value': 16, 'label': 'In what city or town did your mother and father meet?'}, {'value': 17, 'label': 'In what city or town did you meet your spouse/significant other?'}, {'value': 18, 'label': 'In what city or town did you spend your honeymoon?'}, {'value': 19, 'label': 'What city or town were you in at the turn of the millennium?'}, {'value': 20, 'label': 'What city or town did you visit on your first vacation?'}, {'value': 21, 'label': 'What street did you live on when you were in third grade?'}, {'value': 22, 'label': 'What is the street number of the house you grew up in?'}, {'value': 23, 'label': 'What is the name of your elementary / primary school?'}, {'value': 24, 'label': 'What was your favorite activity in high school?'}, {'value': 25, 'label': 'What was your high school mascot?'}, {'value': 26, 'label': 'What was the name of the first band you saw in concert?'}, {'value': 27, 'label': 'What was the model of your first car? (e.g., Thunderbird)'}, {'value': 28, 'label': "What are the last four digits of your driver's license number?"}, {'value': 29, 'label': 'What is the name of a college you applied to but did not attend?'}], 'type': 'select', 'label': 'Question'}, 'securityA2': {'type': 'textInput', 'minChars': 1, 'maxChars': 64, 'label': 'Answer'}, 'securityQ1': {'options': [{'value': 0, 'label': 'What was your childhood nickname?'}, {'value': 1, 'label': "What is your father's middle name?"}, {'value': 2, 'label': "What is your oldest sibling's middle name?"}, {'value': 3, 'label': "What is your youngest sibling's middle name?"}, {'value': 4, 'label': 'What is the last name of your childhood best friend?'}, {'value': 5, 'label': 'What is the last name of the boy or girl that you first kissed?'}, {'value': 6, 'label': 'What is the last name of your third grade teacher?'}, {'value': 7, 'label': 'What is the last name of your fifth grade teacher?'}, {'value': 8, 'label': 'What is the last name of your favorite elementary school teacher?'}, {'value': 9, 'label': 'What is the last name of your favorite high school teacher?'}, {'value': 10, 'label': 'What is the last name of your first roommate during college?'}, {'value': 11, 'label': 'What is the last name of your first boss?'}, {'value': 12, 'label': 'What is the last name of the funniest friend you know?'}, {'value': 13, 'label': 'What was the name of your first pet?'}, {'value': 14, 'label': 'What was the name of your first stuffed animal?'}, {'value': 15, 'label': 'Who was your childhood hero?'}, {'value': 16, 'label': 'In what city or town did your mother and father meet?'}, {'value': 17, 'label': 'In what city or town did you meet your spouse/significant other?'}, {'value': 18, 'label': 'In what city or town did you spend your honeymoon?'}, {'value': 19, 'label': 'What city or town were you in at the turn of the millennium?'}, {'value': 20, 'label': 'What city or town did you visit on your first vacation?'}, {'value': 21, 'label': 'What street did you live on when you were in third grade?'}, {'value': 22, 'label': 'What is the street number of the house you grew up in?'}, {'value': 23, 'label': 'What is the name of your elementary / primary school?'}, {'value': 24, 'label': 'What was your favorite activity in high school?'}, {'value': 25, 'label': 'What was your high school mascot?'}, {'value': 26, 'label': 'What was the name of the first band you saw in concert?'}, {'value': 27, 'label': 'What was the model of your first car? (e.g., Thunderbird)'}, {'value': 28, 'label': "What are the last four digits of your driver's license number?"}, {'value': 29, 'label': 'What is the name of a college you applied to but did not attend?'}], 'type': 'select', 'label': 'Question'}, 'securityA1': {'type': 'textInput', 'minChars': 1, 'maxChars': 64, 'label': 'Answer'}, 'securityQ3': {'options': [{'value': 0, 'label': 'What was your childhood nickname?'}, {'value': 1, 'label': "What is your father's middle name?"}, {'value': 2, 'label': "What is your oldest sibling's middle name?"}, {'value': 3, 'label': "What is your youngest sibling's middle name?"}, {'value': 4, 'label': 'What is the last name of your childhood best friend?'}, {'value': 5, 'label': 'What is the last name of the boy or girl that you first kissed?'}, {'value': 6, 'label': 'What is the last name of your third grade teacher?'}, {'value': 7, 'label': 'What is the last name of your fifth grade teacher?'}, {'value': 8, 'label': 'What is the last name of your favorite elementary school teacher?'}, {'value': 9, 'label': 'What is the last name of your favorite high school teacher?'}, {'value': 10, 'label': 'What is the last name of your first roommate during college?'}, {'value': 11, 'label': 'What is the last name of your first boss?'}, {'value': 12, 'label': 'What is the last name of the funniest friend you know?'}, {'value': 13, 'label': 'What was the name of your first pet?'}, {'value': 14, 'label': 'What was the name of your first stuffed animal?'}, {'value': 15, 'label': 'Who was your childhood hero?'}, {'value': 16, 'label': 'In what city or town did your mother and father meet?'}, {'value': 17, 'label': 'In what city or town did you meet your spouse/significant other?'}, {'value': 18, 'label': 'In what city or town did you spend your honeymoon?'}, {'value': 19, 'label': 'What city or town were you in at the turn of the millennium?'}, {'value': 20, 'label': 'What city or town did you visit on your first vacation?'}, {'value': 21, 'label': 'What street did you live on when you were in third grade?'}, {'value': 22, 'label': 'What is the street number of the house you grew up in?'}, {'value': 23, 'label': 'What is the name of your elementary / primary school?'}, {'value': 24, 'label': 'What was your favorite activity in high school?'}, {'value': 25, 'label': 'What was your high school mascot?'}, {'value': 26, 'label': 'What was the name of the first band you saw in concert?'}, {'value': 27, 'label': 'What was the model of your first car? (e.g., Thunderbird)'}, {'value': 28, 'label': "What are the last four digits of your driver's license number?"}, {'value': 29, 'label': 'What is the name of a college you applied to but did not attend?'}], 'type': 'select', 'label': 'Question'}, 'securityA3': {'type': 'textInput', 'minChars': 1, 'maxChars': 64, 'label': 'Answer'}, 'currentPassword': {'type': 'textInput', 'minChars': 1, 'maxChars': 50}}, 'method': 'POST', 'action': 'rest/adt/ui/client/user/changeSecurityQs&numQs=3', 'numberQsRequired': 3}, 'changeEmailAddress': {'params': {'emailAddress1': {'caption': [{'id': 0, 'label': 'Also used for account messages.'}], 'type': 'textInput', 'minChars': 5, 'maxChars': 255, 'defaultValue': 'tyamell@gmail.com', 'label': 'Send Email Alerts to'}, 'emailAddress3': {'type': 'textInput', 'minChars': 5, 'maxChars': 255}, 'emailAddress2': {'type': 'textInput', 'minChars': 5, 'maxChars': 255}, 'currentPassword': {'type': 'textInput', 'minChars': 1, 'maxChars': 50}}, 'method': 'POST', 'action': 'rest/adt/ui/client/user/changeEmailAddress'}, 'removeSmsNumbers': {'params': {'smsNumber1': {'type': 'boolean', 'defaultValue': False}, 'smsNumber2': {'type': 'boolean', 'defaultValue': False}, 'smsNumber3': {'type': 'boolean', 'defaultValue': False}}, 'method': 'POST', 'action': 'rest/adt/ui/client/user/removeSmsNumbers'}}, 'login': 'tyamell@gmail.com', 'displayName': 'Ty Amell', 'locale': 'en_US', 'temperatureUnit': 'F', 'emailAddress': 'tyamell@gmail.com', 'securityQsSet': True, 'userId': '2451780'}, 'actionURI': 'rest/adt/ui/operations?method=POST&action=/', 'complete': True}, 'operations': {}}, 'ts': 1540585226589, 'type': 'replaceall'}], 'count': 1, 'ts': 1540585226589}"""

class TestADT(unittest.TestCase):
    """Test the ADTPulseAlarm class in adtpulsepy."""

    def setUp(self):
        """Set up test."""
        self.alarms = []
        json_data = UTIL.load_dirty_json(DATA)
        for upd in json_data["update"]:
            self.alarms.append(ADTPulseAlarm(upd["data"]["client"]))

    def tearDown(self):
        """Clean up after test."""
        self.alarms = None

    def test_json(self):
        payload = UTIL.load_dirty_json('{"regExp": "[a-zA-Z0-9\\.\\-\\_, ]?"}')
        self.assertEqual(payload["regExp"], "[a-zA-Z0-9\\.\\-\\_, ]?")

    def tests_sensors(self):
        self.assertEqual(len(self.alarms[0].sensors), 8, "Should have found 8 sensors")

if __name__ == '__main__':
    unittest.main()
